@@ -23,6 +23,7 @@ def cheat(p):
 # --generate / -g
 def generate(p, prompt_default=True):
     """Generates Python file for a problem."""
+    problemText = p.text
 
     msg = "Generate file for problem %i?" % p.num
     click.confirm(msg, default=prompt_default, abort=True)
@@ -39,9 +40,7 @@ def generate(p, prompt_default=True):
     problemHeader = 'Project Euler Problem %i\n' % p.num
     problemHeader += '=' * len(problemHeader.strip()) + '\n\n'
 
-    problemText = p.text
-
-    with open(p.filename, 'w') as file:
+    with open(filename, 'w') as file:
         file.write('"""\n')
         file.write(problemHeader)
         file.write(problemText)
